@@ -6,7 +6,7 @@
 import time
 from functools import wraps
 from sdc_helpers.slack_helper import SlackHelper
-
+from random import random
 
 def retry_handler(
         exceptions,
@@ -35,7 +35,7 @@ def retry_handler(
         def func_with_retries(*args, **kwargs):
             """wrapper function to decorate function with retry functionality"""
             _tries, _delay = total_tries, initial_wait
-            while _tries > 1:
+            while _tries > 0:
                 try:
                     print(f'Attempt {total_tries + 1 - _tries}')
                     return function(*args, **kwargs)
@@ -69,3 +69,36 @@ def retry_handler(
         return func_with_retries
 
     return retry_decorator
+
+def request_handler(
+        wait: float = 0,
+        backoff_factor: float = 0.01,
+        backoff_method: str = 'random'
+):
+    """
+        Decorator - managing API failures
+
+        Args:
+            wait (float, optional): [description]. Defaults to 100 seconds for GoogleAnalytics. Initial delay between retry attempts in seconds
+            backoff_factor (float, optional): [description]. Defaults to 0.1. Multiplier used to further randomize delay
+            backoff_method (str, optional): [description]. Defaults to 'random'. hHow to apply backoff
+        return:
+            wrapped function's response
+    """
+
+    def retry_decorator(function):
+        @wraps(function)
+        def func_with_retries(*args, **kwargs):
+            """wrapper function to decorate function with retry functionality"""
+            if backoff_method == 'random':
+                _delay = wait * (1 + backoff_factor * random())
+            else:
+                _delay = wait
+
+            print(f'Waiting {_delay} seconds before attempt')
+            time.sleep(_delay)
+            return function(*args, **kwargs)
+
+        return func_with_retries
+
+    return retry_decorator
